from unittest.mock import patch

from ..base import BaseTest
from ...modules import autocomplete


class Test(BaseTest):

    def test_set_parameters(self):
        autocomplete.set_parameters(
            list_=['four', 'five', 'six'],
            case_sensitive=False
        )

        assert autocomplete.completion_list == ['four', 'five', 'six']
        assert autocomplete.is_case_sensitive is False

    def test_autocomplete(self):
        autocomplete.set_parameters([
            'one_thing', 'one_other_thing', 'third_thing'])

        with patch('readline.get_line_buffer', return_value='one'):
            assert autocomplete.autocomplete('on', state=0) == 'one_thing'
            assert autocomplete.autocomplete(
                'on', state=1) == 'one_other_thing'
            assert autocomplete.autocomplete('on', state=2) is None

    def test_autocomplete_2(self):
        autocomplete.set_parameters([
            'one_thing', 'one_other_thing', 'third_thing'])

        with patch('readline.get_line_buffer', return_value='ONE'):
            assert autocomplete.autocomplete('on', state=0) is None

    def test_autocomplete_3(self):
        autocomplete.set_parameters(list_=[
            'one_thing', 'one_other_thing', 'third_thing'],
            case_sensitive=False)

        with patch('readline.get_line_buffer', return_value='ONE'):
            assert autocomplete.autocomplete('on', state=0) == 'one_thing'
            assert autocomplete.autocomplete(
                'on', state=1) == 'one_other_thing'
            assert autocomplete.autocomplete('on', state=2) is None

    def test_find_breaking_strings(self):

        assert autocomplete.find_breaking_strings('abc') == 0
        assert autocomplete.find_breaking_strings('abc@def') == 3
        assert autocomplete.find_breaking_strings('abc@def*ghi') == 7
        assert autocomplete.find_breaking_strings(
            'some@email.com somethingelse') == 14

    def test_get_input_autocomplete(self):
        autocomplete.set_parameters([
            'one_thing', 'one_other_thing', 'third_thing'])

        with patch('builtins.input', return_value='some_value'):
            assert autocomplete.get_input_autocomplete() == 'some_value'



from .base import Base

from sqlalchemy import Column, Integer, String


class UserModel(Base):
    __tablename__ = 'users'

    id = Column(Integer, primary_key=True)
    key = Column(String)
    value = Column(String)

    def __repr__(self):
        return "<UserModel(id='%s', key='%s', value='%s')>" % (
            self.id, self.key, self.value)



import os
from ..lib.Encryption import Encryption

def test_encryption_decryption_performance(benchmark):
    """
    Benchmarks the performance of a full encryption and decryption cycle.
    """
    key = os.urandom(32)  # Generate a random 256-bit key
    secret = b"this is a top secret message for performance testing"
    encryption = Encryption(key)

    def f():
        encrypted = encryption.encrypt(secret)
        decrypted = encryption.decrypt(encrypted)
        assert decrypted == secret

    benchmark(f)



import tempfile
import configparser

from ..base import BaseTest
from ...lib.Config import Config


class Test(BaseTest):

    def setUp(self):
        # Use a temporary file to test the config
        file_ = tempfile.NamedTemporaryFile()

        self.config = Config(file_.name)

    def test_get_config(self):
        self.assertIsInstance(self.config.get_config(),
                              configparser.SectionProxy)

    def test_set_default_config_file(self):
        self.assertIsNone(self.config.set_default_config_file())

    def test_update(self):
        self.config.update('some_name', 'some_value')
        retrieved = self.config.get_config()
        self.assertEqual(retrieved['some_name'], 'some_value')
        self.assertTrue(retrieved)

    def test_save_config(self):
        self.config.get_config()
        self.assertTrue(self.config.save_config())

    def test_generate_random_salt(self):
        self.assertIsInstance(self.config.generate_random_salt(), str)

    def test_getattr(self):
        self.assertIsInstance(self.config.salt, str)

    def test_getattr_2(self):
        self.assertIsNone(self.config.some_invalid_value)



import sys
import os

# Add src to path so we can import lib
sys.path.append(os.path.abspath(os.path.join(os.path.dirname(__file__), '..')))

from lib.Encryption import Encryption

def run():
    print("Starting DynaPyt Driver")
    key = b"supersecretkey"
    enc = Encryption(key)
    salt = enc.gen_salt()
    print(f"Generated salt: {salt}")
    digest = enc.digest_key()
    print(f"Digested key: {digest}")
    enc.set_salt()

    ### Another example
    message = b"Encrypt This!!"
    print(f"Original message: {message}")
    ciphertext = enc.encrypt(message)
    print(f"Encrypted message (base64): {ciphertext}")
    plaintext = enc.decrypt(ciphertext)
    print(f"Decrypted message: {plaintext}")
    enc.set_salt(salt)
    secret2 = b"Secret with salt"
    ciphertext2 = enc.encrypt(secret2)
    print(f"Encrypted with salt (base64): {ciphertext2}")
    enc.set_salt(salt)
    plaintext2 = enc.decrypt(ciphertext2)
    print(f"Decrypted with salt: {plaintext2}")
    print("Finished DynaPyt Driver")

if __name__ == "__main__":
    run()



from unittest.mock import patch
import tempfile
from shutil import copyfile

from ..base import BaseTest
from ...views import migration
from ...lib.Config import Config


class Test(BaseTest):

    config_path_to_copy = 'src/unittest/assets/migration/legacy-config'
    vault_path = 'src/unittest/assets/migration/legacy-vault'
    legacy_password = 'password123'

    def setUp(self):
        # Copy config file to a temporary file
        self.config_path = tempfile.NamedTemporaryFile(delete=False)
        copyfile(self.config_path_to_copy, self.config_path.name)

    def test_migrate(self):
        # Successful migration
        file_ = tempfile.NamedTemporaryFile(delete=False)

        with patch('builtins.input', return_value='y'):
            with patch('getpass.getpass', return_value=self.legacy_password):
                self.assertTrue(migration.migrate(vault_path=self.vault_path,
                                                  config_path=self.config_path.name,
                                                  new_vault_path=file_.name))

    def test_migrate_2(self):
        # Migration with confirmation denied
        file_ = tempfile.NamedTemporaryFile(delete=False)

        with patch('builtins.input', return_value='n'):
            with patch('getpass.getpass', return_value=self.legacy_password):
                self.assertFalse(migration.migrate(vault_path=self.vault_path,
                                                   config_path=self.config_path.name,
                                                   new_vault_path=file_.name))

    def test_migrate_3(self):
        with patch('getpass.getpass', return_value='some invalid password'):
            self.assertRaises(SystemExit, migration.migrate,
                              vault_path=self.vault_path, config_path=self.config_path.name)

    def update_config(self):
        migration.update_config()
        self.assertEqual(migration.config.version, '2.00')
        self.assertEqual(migration.config.encrypteddb, True)

    def test_unlock(self):
        vault_content = migration.unlock(self.vault_path, self.legacy_password)
        self.assertIsInstance(vault_content, dict)
        self.assertIsInstance(vault_content['secrets'], list)
        self.assertIsInstance(vault_content['categories'], list)

    def test_get_hash(self):
        migration.config = Config(self.config_path.name)
        self.assertEqual(migration.get_hash(
            self.legacy_password), b'\xd3\xbe[{\xad6k^|\xd7\xbe\x9f\xd5\xef7o\xd7\xbbq\xce\xf7\xe9\xb7x')

    def test_prepare_items(self):
        vault_content = migration.unlock(self.vault_path, self.legacy_password)
        prepared = migration.prepare_items(
            vault_content['secrets'], vault_content['categories'])

        # The result should be a list
        self.assertIsInstance(prepared, list)

        # Loop thru items to check them
        for item in prepared:
            self.assertIsInstance(item, dict)
            self.assertIsInstance(item['name'], str)
            self.assertIsNone(item['url'])
            self.assertIsInstance(item['login'], str)
            self.assertIsInstance(item['password'], str)
            self.assertIsInstance(item['notes'], str)
            self.assertTrue(item['category'] is None or isinstance(
                item['category'], str))

    def test_get_category_name(self):
        # With valid ID
        self.assertEqual(migration.get_category_name(id_=0, categories=[
            {'name': 'Business', 'active': True}, {'name': 'Perso', 'active': True}]), 'Business')

    def test_get_category_name_2(self):
        # With invalid category
        self.assertIsNone(migration.get_category_name(id_=1, categories=[
            {'name': 'Business', 'active': True}, {'name': 'Perso', 'active': False}]))

    def test_get_category_name_3(self):
        # Without an ID
        self.assertIsNone(migration.get_category_name(id_=None, categories=[
                          {'name': 'Business', 'active': True}, {'name': 'Perso', 'active': True}]))
